@@ -9,7 +9,7 @@ https://raw.github.com/bengillies/chrjs.store/master/dist/chrjs-store-latest.js
  *
  * Dependencies: chrjs library, jQuery, TiddlySpace
  *
- * Version: 0.6.6
+ * Version: 0.7.0
  *
  * created by Ben Gillies
  * Chrjs-Store is distributed under a BSD License
@@ -1254,10 +1254,12 @@ return function(container) {
 	// defaultContainer hasn't been discovered yet.
 	var getDefaultContainer = function(callback) {
 		var returnContainer = function(container) {
-			$.each(callbackQueue, function(i, fn) {
+			// queue up callbacks and call all of them once the one ajax call completes
+			var fn;
+			while (callbackQueue.length > 0) {
+				fn = callbackQueue.shift();
 				fn(container);
-			});
-			callbackQueue = [];
+			}
 			return container;
 		};
 
@@ -1266,8 +1268,10 @@ return function(container) {
 		}
 
 		if (defaultContainer) {
+			// no ajax call necessary so return immediately
 			return returnContainer(defaultContainer);
 		} else if (callbackQueue.length === 0) {
+			// only make one ajax call
 			determineContainer(function(container) {
 				defaultContainer = container;
 				returnContainer(container);
@@ -1362,8 +1366,9 @@ define('utils',[],function() {
 define('refresh',['utils'], function(utils) {
 
 return function(ev) {
-	var containers = {};
-	var replace = utils.replace(ev);
+	var containers = {},
+		replace = utils.replace(ev),
+		sockets = typeof io !== 'undefined';
 
 	var _removeDeleted = function(store, tiddlers) {
 		var keys = $.map(tiddlers, function(tid) { return tid.bag.name + tid.title; });
@@ -1392,6 +1397,58 @@ return function(ev) {
 		});
 	};
 
+	// only support websockets with bags and recipes
+	var _addSocket = function(sock, thing, store) {
+		var getTiddler = function(uri) {
+			var title = decodeURIComponent(uri.replace(/.*\//, ''));
+			return new tiddlyweb.Tiddler(title, thing);
+		};
+
+		var subscribeRecipe = function(recipe) {
+			$.each(recipe, function(i, bagFilterCombo) {
+				sock.emit('subscribe', 'bag/' + bagFilterCombo[0]);
+			});
+			sock.on('tiddler', function(uri) {
+				var tid = getTiddler(uri),
+					bagName = decodeURIComponent(uri.split('/')[2]);
+				tid.get(function(t) {
+					// if it's an update for a tiddler clobbered by the recipe
+					// bag stack, then ignore it
+					if (t.bag.name === bagName) {
+						replace(store, t);
+					}
+				}, function() {});
+			});
+		};
+
+		if (thing instanceof tiddlyweb.Recipe) {
+			if (thing.recipe.length === 0) {
+				thing.get(function(recipe) {
+					subscribeRecipe(recipe.recipe);
+				}, function() {}); // fail silently
+			} else {
+				subscribeRecipe(thing.recipe);
+			}
+		} else if (thing instanceof tiddlyweb.Bag) {
+			sock.emit('subscribe', 'bag/' + thing.name);
+			sock.on('tiddler', function(uri) {
+				var tid = getTiddler(uri);
+				tid.get(function(t) {
+					replace(store, t);
+				}, function() {}); // if error, then ignore the notification
+			});
+		}
+	};
+
+	// feature detect websockets and only use if they exist
+	var addSocket = (sockets) ? function(thing, store) {
+			var sock = io.connect(window.location.protocol + '//' +
+				window.location.hostname + ':8081');
+			sock.on('connect', function() {
+				_addSocket(sock, thing, store);
+			});
+		} : function() {};
+
 	return {
 		refresh: function(thing, callback) {
 			if (typeof thing !== 'function') {
@@ -1407,6 +1464,7 @@ return function(ev) {
 				tiddlers: (thing.tiddlers) ? thing.tiddlers() : thing,
 				store: store
 			};
+			addSocket(thing, store);
 		},
 		each: function(callback) {
 			$.each(containers, function(i, obj) {
@@ -1452,9 +1510,8 @@ return function(tiddlerCallback, getCached, defaultContainers) {
 			// pullFrom: default location to refresh the store from
 			// pushTo: default location to save to
 			var res = defaults.getDefault(function(defaults) {
-				self.recipe = defaults.pullFrom;
-				containers.set(store, defaults.pullFrom);
 				if (callback) {
+					self.recipe = defaults.pullFrom;
 					callback(defaults);
 				}
 			});
@@ -1465,7 +1522,13 @@ return function(tiddlerCallback, getCached, defaultContainers) {
 
 	$.extend(self, {
 		refresh: function(callback) {
-			self.getDefaults(function() {
+			self.getDefaults(function(defaults) {
+				// if no containers set, use the default one
+				var noContainers = true;
+				containers.each(function() { noContainers = false; });
+				if (noContainers) {
+					containers.set(store, defaults.pullFrom);
+				}
 				containers.refresh(function(tiddlers) {
 					if (tiddlers) {
 						callback.call(self, collection(self, tiddlers));
