@@ -6,7 +6,7 @@ https://raw.github.com/TiddlySpace/ts.js/master/src/ts.js
 /*global jQuery, tiddlyweb, confirm, prompt */
 //
 // version 0.5.12
-(function($, window) {
+(function($) {
 	"use strict";
 
 	var getCSRFToken = function() {
@@ -90,6 +90,63 @@ https://raw.github.com/TiddlySpace/ts.js/master/src/ts.js
 		}).appendTo(container);
 	}
 
+	/*
+	 * Do the default initialization behaviors.
+	 */
+	function defaultInit(ts, status, callback, options) {
+		options = options || {};
+		if (status.space && status.space.name &&
+				typeof options.space === "undefined") {
+			options.space = status.space.name;
+		}
+		ts.resolveCurrentSpaceName(options, status.server_host.host);
+		if(!ts.currentSpace) {
+			$(document.body).addClass("ts-unknown-space");
+		}
+		ts.loadStatus(status);
+		if(status.identity || ts.parameters.openid) {
+			ts.register_openid(status.identity);
+		} else if(status.username && ts.parameters.openid) {
+			// open id login occurred so redirect to homespace
+			window.location.href = ts.parameters.redirect ||
+				ts.getHost(status.username);
+		}
+		// do login status
+		ts.forms.password($("form.ts-password")[0]);
+		ts.loginStatus();
+		if(ts.currentSpace) {
+			ts.initForSpace(status);
+		}
+		if(callback) {
+			callback(ts);
+		}
+	}
+
+	/*
+	 * Parse query parameters into a simple object.
+	 */
+	function parseParameters(queryString) {
+		var args = queryString.split(/[&;]/),
+			parameters = {},
+			i,
+			nameval;
+		for(i = 0; i < args.length; i += 1) {
+			nameval = args[i].split("=");
+			if(nameval.length === 2) {
+				parameters[nameval[0]] = nameval[1];
+			}
+		}
+		return parameters;
+	}
+
+	/*
+	 * add CSRF form fields to the provided form.
+	 */
+	function addCSRF(form) {
+		$('<input type="hidden" name="csrf_token" />').
+			val(getCSRFToken()).appendTo(form);
+	}
+
 	var ts = {
 		currentSpace: false,
 		locale: {
@@ -123,46 +180,10 @@ https://raw.github.com/TiddlySpace/ts.js/master/src/ts.js
 			return name.match(/^[a-z][0-9a-z\-]*[0-9a-z]$/) ? true : false;
 		},
 		init: function(callback, options) {
-			ts.loadHash();
-			var register = $("form.ts-registration").addClass("tsInitializing")[0];
-			var login = $("form.ts-login").addClass("tsInitializing")[0];
-			var logout = $(".ts-logout").addClass("tsInitializing")[0];
-			var openid = $("form.ts-openid")[0];
-
-			$("input[type=submit]", [login, logout, register, openid]).
-				attr("disabled", true);
+			ts.parameters = parseParameters(window.location.search.substr(1));
 			var status = tiddlyweb.status;
 			if (status) {
-				options = options || {};
-				if (status.space && status.space.name && typeof options.space === "undefined") {
-					options.space = status.space.name;
-				}
-				ts.resolveCurrentSpaceName(options, status.server_host.host);
-				if(!ts.currentSpace) {
-					$(document.body).addClass("ts-unknown-space");
-				}
-				$(register).removeClass("tsInitializing");
-				$(login).removeClass("tsInitializing");
-				$(logout).removeClass("tsInitializing");
-				$("input[type=submit]", [login, logout, register, openid]).
-					attr("disabled", false);
-				ts.loadStatus(status);
-				if(status.identity || ts.parameters.openid) {
-					ts.register_openid(status.identity);
-				} else if(status.username && ts.parameters.openid) {
-					// open id login occurred so redirect to homespace
-					window.location.href = ts.parameters.redirect ||
-						ts.getHost(status.username);
-				}
-				// do login status
-				ts.forms.password($("form.ts-password")[0]);
-				ts.loginStatus(login, register, logout);
-				if(ts.currentSpace) {
-					ts.initForSpace(status);
-				}
-				if(callback) {
-					callback(ts);
-				}
+				defaultInit(ts, status, callback, options);
 			}
 		},
 		initForSpace: function(status) {
@@ -222,6 +243,7 @@ https://raw.github.com/TiddlySpace/ts.js/master/src/ts.js
 			var success = options.success || function() {
 				window.location = options.redirect || ts.getHost(username);
 			};
+			// XXX void errback?
 			var errback = options.errback || function() {};
 			var challenger = options.challenger = options.challenger ||
 				"tiddlywebplugins.tiddlyspace.cookie_form";
@@ -232,7 +254,7 @@ https://raw.github.com/TiddlySpace/ts.js/master/src/ts.js
 				data: {
 					user: username,
 					password: password,
-					csrf_token: window.getCSRFToken(),
+					csrf_token: getCSRFToken(),
 					// workaround to marginalize automatic subsequent GET
 					tiddlyweb_redirect: "/status"
 				},
@@ -241,17 +263,6 @@ https://raw.github.com/TiddlySpace/ts.js/master/src/ts.js
 			});
 		},
 		parameters: {},
-		loadHash: function() {
-			var args = window.location.search.substr(1).split("&"),
-				i,
-				nameval;
-			for(i = 0; i < args.length; i += 1) {
-				nameval = args[i].split("=");
-				if(nameval.length === 2) {
-					ts.parameters[nameval[0]] = nameval[1];
-				}
-			}
-		},
 		register_openid_for_user: function(username, openid) {
 			var user = new tiddlyweb.User(username, null, "/");
 			user.identities().add(openid, function() {
@@ -346,7 +357,11 @@ https://raw.github.com/TiddlySpace/ts.js/master/src/ts.js
 			var user = new tiddlyweb.User(username, password, "/");
 			user.setPassword(npassword, pwCallback, pwErrback);
 		},
-		loginStatus: function(login, register, logout) {
+		loginStatus: function() {
+			var register = $("form.ts-registration");
+			var login = $("form.ts-login");
+			var logout = $(".ts-logout");
+
 			var user = ts.user;
 			$("form.ts-openid").each(function(i, el) {
 				ts.forms.openid(el, { user: user });
@@ -354,7 +369,7 @@ https://raw.github.com/TiddlySpace/ts.js/master/src/ts.js
 			if(!user.anon) {
 				$(document.body).addClass("ts-loggedin");
 				$([register, login]).remove();
-				$(".ts-logout").each(function(i, el) {
+				logout.each(function(i, el) {
 					ts.forms.logout(el);
 				});
 			} else {
@@ -364,7 +379,7 @@ https://raw.github.com/TiddlySpace/ts.js/master/src/ts.js
 				if(login) {
 					ts.forms.login(login);
 				}
-				$(".ts-logout").remove();
+				logout.remove();
 			}
 		}
 	};
@@ -386,15 +401,11 @@ https://raw.github.com/TiddlySpace/ts.js/master/src/ts.js
 				return false;
 			});
 		},
-		csrf: function(form) {
-			$('<input type="hidden" name="csrf_token" />').
-				val(window.getCSRFToken()).appendTo(form);
-		},
 		addInclude: function(form) {
 			if(!form) {
 				return;
 			}
-			ts.forms.csrf(form);
+			addCSRF(form);
 			$(form).submit(function(ev) {
 				ev.preventDefault();
 				var input = $("input[name=spacename]", form);
@@ -402,7 +413,8 @@ https://raw.github.com/TiddlySpace/ts.js/master/src/ts.js
 				var callback = function(data, status, xhr) {
 					ts.lists.includes($("ul.ts-includes").empty()[0]);
 					input.val("");
-					resetMessage(form);
+					var msg = space + ' included';
+					displayMessage(form, msg, false);
 				};
 				var errback = function(xhr, error, exc) {
 					var msg = "Unable to include space with that name.";
@@ -416,7 +428,7 @@ https://raw.github.com/TiddlySpace/ts.js/master/src/ts.js
 			if(!form) {
 				return;
 			}
-			ts.forms.csrf(form);
+			addCSRF(form);
 			$(form).submit(function(ev) {
 				ev.preventDefault();
 				var input = $("input[name=username]", form);
@@ -456,7 +468,7 @@ https://raw.github.com/TiddlySpace/ts.js/master/src/ts.js
 				return;
 			}
 			var selector = "[name=spacename]";
-			ts.forms.csrf(form);
+			addCSRF(form);
 			$(form).submit(function(ev) {
 				ev.preventDefault();
 				var spaceName = $(selector, form).val() || "";
@@ -475,7 +487,7 @@ https://raw.github.com/TiddlySpace/ts.js/master/src/ts.js
 		},
 		register: function(form, options) {
 			options = options || {};
-			ts.forms.csrf(form);
+			addCSRF(form);
 			$(form).submit(function(ev) {
 				ev.preventDefault();
 				var username = $("[name=username]", form).val();
@@ -501,7 +513,7 @@ https://raw.github.com/TiddlySpace/ts.js/master/src/ts.js
 			});
 		},
 		openid: function(form, options) {
-			ts.forms.csrf(form);
+			addCSRF(form);
 			$(form).attr("method", "post").
 				attr("action",
 						"/challenge/tiddlywebplugins.tiddlyspace.openid").
@@ -558,11 +570,11 @@ https://raw.github.com/TiddlySpace/ts.js/master/src/ts.js
 				form = form_or_container;
 			}
 			$(form).attr("action", "/logout").attr("method", "post");
-			ts.forms.csrf(form);
+			addCSRF(form);
 		},
 		login: function(form) {
 			// do login
-			ts.forms.csrf(form);
+			addCSRF(form);
 			var options = {
 				errback: function(xhr, error, exc) {
 					var code = xhr.status;
@@ -693,9 +705,10 @@ https://raw.github.com/TiddlySpace/ts.js/master/src/ts.js
 			}
 		}
 	};
+	ts.parseParameters = parseParameters;
 	window.ts = {
 		init: ts.init
 	};
 
-}(jQuery, window));
+}(jQuery));
 //}}}
