@@ -10,7 +10,7 @@ from tiddlywebplugins.utils import replace_handler
 
 from tiddlywebplugins.tiddlyspace.controlview import (ControlView,
         DropPrivs, AllowOrigin)
-from tiddlywebplugins.tiddlyspace.csrf import CSRFProtector
+from tiddlywebplugins.csrf import CSRFProtector
 from tiddlywebplugins.tiddlyspace.serversettings import ServerSettings
 from tiddlywebplugins.tiddlyspace.handler import (home, friendly_uri,
         get_identities, get_space_tiddlers)
